/***********************************************************
*       libsrs_alt - A simple SRS implementation           *
***********************************************************/

/* 2004 Miles Wilton <miles@mirtol.com> */

/* License: GPL */

/* This file:

   timestamp.c

   <no description>
*/

#include <string.h>

#include "hash.h"
#include "address.h"



/***********************************************************
    srs_hash

*/

srs_result srs__hash(srs_t *srs, char *data, uint data_len, char *md, uint *md_len)
{
    mHMAC hmac;
    
    mHMAC_start(&hmac, &mHMACD_SHA1, srs->secret, srs->secret_len);
    mHMAC_process(&hmac, data, data_len);
    mHMAC_end(&hmac, md);

    *md_len = 20;

    return SRS_RESULT_OK;
}


/***********************************************************
    srs__hash_verify

*/

srs_result srs__hash_verify(srs_t *srs, char *data, uint data_len, char *hash, uint hash_len)
{
    char buf[128];
    char md[mHMAC_MAX_HASH_LEN];
    uint n;

    if(hash_len < srs->hash_min)
        return SRS_RESULT_HASHTOOSHORT;

    // Perform hash
    srs__hash(srs, data, data_len, md, &n);

    // Base64 encode it
    srs__base64enc(md, n, buf, 128);

    if(strncmp(buf, hash, hash_len) != 0)
    {
        if(strncasecmp(buf, hash, hash_len) != 0)
            return SRS_RESULT_FAIL;
        else
            return SRS_RESULT_CASEBROKEN;
    }

    return SRS_RESULT_OK;
}

